Pro fors2_info,filenames,filelist=filelist,outfile=outfile

;+----------------------------------------------------------------------
;
; FORS2_INFO      5/2004
;
; Extract useful information from a FORS2 fits file header,
; including target name, integration time, slit, grism,
; arimass, etc..
;
; INPUTS
;        file     - (Optional) String array of fits filenames.
;
; KEYWORDS
;        filelist - String, name of single-column ASCII file 
;                   containing names of FITS files to be read.  Can
;                   be set instead of 'file' input.
;        outfile  - File to which to direct output (one line per input
;                   fits file)
;
; PROGRAMS CALLED
;        strsetlen
;
; HISTORY
;        Modified from LRIS_INFO 10/23/2006 GDB
;-----------------------------------------------------------------------

if (n_params() eq 0 and not(keyword_set(filelist))) then begin
   print,'CALLING SEQUENCE:'
   print,'  fors2_info,filenames,filelist=filelist,outfile=outfile'
   return
endif

;;; Optional - Read in list of files
if keyword_set(filelist) then begin
   templ = {   $
          version: 1.0, $    
          datastart: 0L, $   
          delimiter: ' ', $
          missingvalue: -99.0, $
          commentsymbol: '#', $
          fieldcount: 1L, $
          fieldtypes: 7L, $
          fieldnames: 'name', $
          fieldlocations: 0L, $
          fieldgroups: [0L] $
        }
    filedata = read_ascii(filelist,template=templ)
    filenames = filedata.name
endif

;;; Optional - Output to a file
tofile = 0    ; Default is standard output
if keyword_set(outfile) then begin
   tofile = 1
   openw,lun,outfile,/get_lun
   ; Print file header
   printf,lun,'# Archive_Filename                TARGET          RA'+$
              '          DEC          EXP    AIRM  FILTER  SLIT  GRIS'+$
              '         DCATG         DTYPE       DTECH       CHIP BIN  WINDOW'
endif

;;; Loop through input files and extract header information

filenames = [filenames]
nfiles = n_elements(filenames)

for i=0,nfiles-1 do begin
   
   ; Read header
   file = filenames(i)
   print,'Reading '+file
   sxhread,file,hdr

   ; Get Keywords and trim to specified length
   arcfile     = strsetlen(filename(gxpar(hdr,'ARCFILE'),/noexten),34)
   target      = strsetlen(gxpar(hdr,'HIERARCH ESO OBS TARG NAME'),16)
   ra_decimal  = gxpar(hdr,'RA',count=ra_count)
   dec_decimal = gxpar(hdr,'DEC',count=dec_count)
   if (ra_count ne 0) then begin
      radec = coordconvert(ra_decimal,dec_decimal,shex=coords,/noprint)
      ra    = coords(0)+' '
      dec   = coords(1)+'  '
   endif else begin
      ra    = '-1           '
      dec   = '-1          '     
   endelse
   exp         = strsetlen(gxpar(hdr,'EXPTIME'),5)+'  '
   airm        = strsetlen(gxpar(hdr,'AIRMASS'),4)+'  '
   filter      = strsetlen(gxpar(hdr,'FILTER1'),6)+'  '
   slit        = strsetlen(gxpar(hdr,'HIERARCH ESO INS SLIT WID'),4)+'  '
   grism       = strsetlen(gxpar(hdr,'HIERARCH ESO INS OPTI6 NAME'),11)+'  '
   catg        = strsetlen(gxpar(hdr,'HIERARCH ESO DPR CATG'),12)+'  '
   type        = strsetlen(gxpar(hdr,'HIERARCH ESO DPR TYPE'),10)+'  '
   tech        = strsetlen(gxpar(hdr,'HIERARCH ESO DPR TECH'),10)+'  '
   extname     = strtrim(sxpar(hdr,'EXTNAME'),2)    ; No '/' in parameter entry.
   if (extname eq 'CHIP1') then chip = '1    ' else chip = '2    '
   xbin        = gxpar(hdr,'HIERARCH ESO DET WIN1 BINX')
   ybin        = gxpar(hdr,'HIERARCH ESO DET WIN1 BINY')
   bin         = strtrim(xbin,2)+'x'+strtrim(ybin,2)+'  '
   n1          = gxpar(hdr,'NAXIS1')
   n2          = gxpar(hdr,'NAXIS2')
   windows     = strtrim(n1,2)+'x'+strtrim(n2,2)+'  '

   ; Print out results
   entry = arcfile+$    
           target +$    
           ra     +$    
           dec    +$    
           exp    +$    
           airm   +$    
           filter +$    
           slit   +$    
           grism  +$    
           catg   +$    
           type   +$    
           tech   +$
           chip   +$    
           bin    +$    
           windows
   if (tofile) then printf,lun,entry else print,entry

endfor

if (tofile) then close,lun

return
end


