Function readfors2,filename,hdr,notrim=notrim,subbias=subbias,_extra=_extra

;+------------------------------------------------------------------
;
; READFORS2          10/2006
;
; Wrapper for READFITS to read in FORS2 image and trim pre/overscan
; regions.
;
; INPUTS
;         filename   - String, FITS filename
;
; KEYWORDS
;         notrim     - If set, will not remove pre/overscan regions.
;                      Default is to return 2048x1024 array.
;         subbias    - Measure bias level from prescan region and
;                      subtract from entire array.  Effective only
;                      if the pre/overscan regions are present.
;         _extra     - READFITS keywords
;
; OUTPUTS
;         <result>   - 2D image array, 2048x1024, unless /notrim 
;                      keyword is set
;         hdr        - String, FITS header
; 
; Written 10/25/2006
;-------------------------------------------------------------------

if (n_params() eq 0) then begin
   print,'CALLING SEQUENCE:'
   print,'     array = readfors2(filename,hdr,/notrim,/subbias,_extra=_extra)'
   return,-1
endif

; Read FITS file
whole_array = readfits(filename,hdr,_extra=_extra)

; Get size of original array
sz  = size(whole_array)
ysz = sz(2)

; Bias subtract (optional)
if keyword_set(subbias) then begin
   ; Determine which CCD
   chip = strtrim(sxpar(hdr,'EXTNAME'),2)
   case chip of
      'CHIP1': ccd_num = 1
      'CHIP2': ccd_num = 2
      else:    ccd_num = 0 ; Unknown CCD number
   endcase
   whole_array = fors2_subbias(whole_array,ccd=ccd_num)
endif

; Trim pre/overscan regions
if not(keyword_set(notrim)) then begin
   ; Trim only if original array includes pre/overscan regions
   case ysz of
      1024: array = whole_array
      1034: begin
               array = whole_array(*,5:1028)
               print,'Removed pre/overscan regions.'
            end
      else: begin
               print,'Original array has unrecognized y-dimension.'
               return,-1
            end
   endcase
endif else array = whole_array

return,array
end
